@@ -53,17 +53,10 @@ GCRY_THREAD_OPTION_PTHREAD_IMPL;
 #define DEBUG(...)
 #endif
 
-#define FSP_SESSION_GET_PRIVATE(object)                 \
-  (G_TYPE_INSTANCE_GET_PRIVATE ((object),               \
-                                FSP_TYPE_SESSION,       \
-                                FspSessionPrivate))
-
-G_DEFINE_TYPE (FspSession, fsp_session, G_TYPE_OBJECT)
-
-
-/* Private struct */
-struct _FspSessionPrivate
+struct _FspSession
 {
+  GObject parent;
+
   gchar *api_key;
   gchar *secret;
   gchar *token;
@@ -77,6 +70,8 @@ struct _FspSessionPrivate
   SoupSession *soup_session;
 };
 
+G_DEFINE_TYPE (FspSession, fsp_session, G_TYPE_OBJECT)
+
 /* Signals */
 enum {
   DATA_FRACTION_SENT,
@@ -359,17 +354,16 @@ fsp_session_set_property                (GObject      *object,
                                          GParamSpec   *pspec)
 {
   FspSession *self = FSP_SESSION (object);
-  FspSessionPrivate *priv = self->priv;
 
   switch (prop_id)
     {
     case PROP_API_KEY:
-      g_free (priv->api_key);
-      priv->api_key = g_value_dup_string (value);
+      g_free (self->api_key);
+      self->api_key = g_value_dup_string (value);
       break;
     case PROP_SECRET:
-      g_free (priv->secret);
-      priv->secret = g_value_dup_string (value);
+      g_free (self->secret);
+      self->secret = g_value_dup_string (value);
       break;
     case PROP_TOKEN:
       fsp_session_set_token (self, g_value_get_string (value));
@@ -394,16 +388,16 @@ fsp_session_get_property                (GObject    *object,
   switch (prop_id)
     {
     case PROP_API_KEY:
-      g_value_set_string (value, self->priv->api_key);
+      g_value_set_string (value, self->api_key);
       break;
     case PROP_SECRET:
-      g_value_set_string (value, self->priv->secret);
+      g_value_set_string (value, self->secret);
       break;
     case PROP_TOKEN:
-      g_value_set_string (value, self->priv->token);
+      g_value_set_string (value, self->token);
       break;
     case PROP_TOKEN_SECRET:
-      g_value_set_string (value, self->priv->token_secret);
+      g_value_set_string (value, self->token_secret);
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -417,16 +411,16 @@ fsp_session_dispose                     (GObject* object)
   FspSession *self = FSP_SESSION (object);
 
   /* Unref object */
-  if (self->priv->soup_session)
+  if (self->soup_session)
     {
-      g_object_unref (self->priv->soup_session);
-      self->priv->soup_session = NULL;
+      g_object_unref (self->soup_session);
+      self->soup_session = NULL;
     }
 
-  if (self->priv->proxy_uri)
+  if (self->proxy_uri)
     {
-      soup_uri_free (self->priv->proxy_uri);
-      self->priv->proxy_uri = NULL;
+      soup_uri_free (self->proxy_uri);
+      self->proxy_uri = NULL;
     }
 
   /* Call superclass */
@@ -439,12 +433,12 @@ fsp_session_finalize                    (GObject* object)
   FspSession *self = FSP_SESSION (object);
 
   /* Free memory */
-  g_free (self->priv->api_key);
-  g_free (self->priv->secret);
-  g_free (self->priv->token);
-  g_free (self->priv->token_secret);
-  g_free (self->priv->tmp_token);
-  g_free (self->priv->tmp_token_secret);
+  g_free (self->api_key);
+  g_free (self->secret);
+  g_free (self->token);
+  g_free (self->token_secret);
+  g_free (self->tmp_token);
+  g_free (self->tmp_token_secret);
 
   /* Call superclass */
   G_OBJECT_CLASS (fsp_session_parent_class)->finalize(object);
@@ -487,33 +481,28 @@ fsp_session_class_init                  (FspSessionClass *klass)
                   0, NULL, NULL,
                   g_cclosure_marshal_VOID__DOUBLE,
                   G_TYPE_NONE, 1, G_TYPE_DOUBLE);
-
-  /* Add private */
-  g_type_class_add_private (obj_class, sizeof (FspSessionPrivate));
 }
 
 static void
 fsp_session_init                        (FspSession *self)
 {
-  self->priv = FSP_SESSION_GET_PRIVATE (self);
-
-  self->priv->api_key = NULL;
-  self->priv->secret = NULL;
-  self->priv->token = NULL;
-  self->priv->token_secret = NULL;
-  self->priv->tmp_token = NULL;
-  self->priv->tmp_token_secret = NULL;
-  self->priv->using_default_proxy = TRUE;
-  self->priv->proxy_uri = NULL;
+  self->api_key = NULL;
+  self->secret = NULL;
+  self->token = NULL;
+  self->token_secret = NULL;
+  self->tmp_token = NULL;
+  self->tmp_token_secret = NULL;
+  self->using_default_proxy = TRUE;
+  self->proxy_uri = NULL;
 
   /* Early gcrypt initialization */
   _init_gcrypt ();
 
 #ifdef SOUP_VERSION_2_42
   /* soup_session_async_new() deprecated in lisoup 2.42 */
-  self->priv->soup_session = soup_session_new ();
+  self->soup_session = soup_session_new ();
 #else
-  self->priv->soup_session = soup_session_async_new ();
+  self->soup_session = soup_session_async_new ();
 #endif
 }
 
@@ -548,7 +537,7 @@ static SoupSession *
 _get_soup_session                       (FspSession *self)
 {
   g_return_val_if_fail (FSP_IS_SESSION (self), NULL);
-  return self->priv->soup_session;
+  return self->soup_session;
 }
 
 static void
@@ -1085,24 +1074,17 @@ _check_async_errors_on_finish           (GObject       *object,
                                          gpointer       source_tag,
                                          GError       **error)
 {
-  gboolean errors_found = TRUE;
-
   g_return_val_if_fail (G_IS_OBJECT (object), FALSE);
-  g_return_val_if_fail (G_IS_ASYNC_RESULT (res), FALSE);
+  g_return_val_if_fail (G_IS_TASK (res), FALSE);
 
-  if (g_simple_async_result_is_valid (res, object, source_tag))
+  GTask *task = G_TASK (res);
+  if (!g_async_result_is_tagged (res, source_tag) || !g_task_is_valid (task, object))
     {
-      GSimpleAsyncResult *simple = NULL;
-
-      /* Check error */
-      simple = G_SIMPLE_ASYNC_RESULT (res);
-      if (!g_simple_async_result_propagate_error (simple, error))
-	errors_found = FALSE;
+      g_set_error_literal (error, FSP_ERROR, FSP_ERROR_OTHER, "Internal error");
+      return TRUE;
     }
-  else
-    g_set_error_literal (error, FSP_ERROR, FSP_ERROR_OTHER, "Internal error");
 
-  return errors_found;
+  return FALSE;
 }
 
 
@@ -1246,7 +1228,6 @@ _get_signed_url                       (FspSession          *self,
                                        const gchar         *first_param,
                                        ... )
 {
-  FspSessionPrivate *priv = NULL;
   va_list args;
   GHashTable *table = NULL;
   gchar *signing_key = NULL;
@@ -1260,18 +1241,17 @@ _get_signed_url                       (FspSession          *self,
   g_return_val_if_fail (url != NULL, NULL);
   g_return_val_if_fail (first_param != NULL, NULL);
 
-  priv = self->priv;
   va_start (args, first_param);
 
   if (token_type == TOKEN_TYPE_PERMANENT)
     {
-      token = priv->token;
-      token_secret = priv->token_secret;
+      token = self->token;
+      token_secret = self->token_secret;
     }
   else
     {
-      token = priv->tmp_token;
-      token_secret = priv->tmp_token_secret;
+      token = self->tmp_token;
+      token_secret = self->tmp_token_secret;
     }
 
   /* Get the hash table for the params */
@@ -1280,15 +1260,15 @@ _get_signed_url                       (FspSession          *self,
   /* Fill the table with mandatory parameters */
   if (auth_method == AUTHORIZATION_METHOD_OAUTH_1)
     {
-      _fill_hash_table_with_oauth_params (table, priv->api_key, token);
-      signing_key = g_strdup_printf ("%s&%s", priv->secret, token_secret ? token_secret : "");
+      _fill_hash_table_with_oauth_params (table, self->api_key, token);
+      signing_key = g_strdup_printf ("%s&%s", self->secret, token_secret ? token_secret : "");
     }
   else
     {
-      g_hash_table_insert (table, g_strdup ("api_key"), g_strdup (priv->api_key));
+      g_hash_table_insert (table, g_strdup ("api_key"), g_strdup (self->api_key));
       if (token)
         g_hash_table_insert (table, g_strdup ("auth_token"), g_strdup (token));
-      signing_key = g_strdup (priv->secret);
+      signing_key = g_strdup (self->secret);
     }
 
   api_sig = _get_api_signature_from_hash_table (url, table, signing_key, "GET", auth_method);
@@ -1312,21 +1292,18 @@ _get_signed_url                       (FspSession          *self,
 static void
 _clear_temporary_token                (FspSession *self)
 {
-  FspSessionPrivate *priv = NULL;
-
   g_return_if_fail (FSP_IS_SESSION (self));
 
-  priv = self->priv;
-  if (priv->tmp_token)
+  if (self->tmp_token)
     {
-      g_free (priv->tmp_token);
-      priv->tmp_token = NULL;
+      g_free (self->tmp_token);
+      self->tmp_token = NULL;
     }
 
-  if (priv->tmp_token_secret)
+  if (self->tmp_token_secret)
     {
-      g_free (priv->tmp_token_secret);
-      priv->tmp_token_secret = NULL;
+      g_free (self->tmp_token_secret);
+      self->tmp_token_secret = NULL;
     }
 }
 
@@ -1444,7 +1421,7 @@ _build_async_result_and_complete        (AsyncRequestData *clos,
                                          gpointer    result,
                                          GError     *error)
 {
-  GSimpleAsyncResult *res = NULL;
+  GTask *task = NULL;
   GObject *object = NULL;
   GCancellableData *cancellable_data = NULL;
   GCancellable *cancellable = NULL;
@@ -1473,19 +1450,16 @@ _build_async_result_and_complete        (AsyncRequestData *clos,
   g_idle_add ((GSourceFunc) _disconnect_cancellable_on_idle, cancellable_data);
 
   /* Build response and call async callback */
-  res = g_simple_async_result_new (object, callback,
-                                   data, source_tag);
+  task = g_task_new (object, cancellable, callback, data);
+  g_task_set_source_tag (task, source_tag);
 
   /* Return the given value or an error otherwise */
   if (error != NULL)
-    g_simple_async_result_set_from_error (res, error);
+    g_task_return_error (task, error);
   else
-    g_simple_async_result_set_op_res_gpointer (res, result, NULL);
+    g_task_return_pointer (task, result, NULL);
 
-  /* Execute the callback */
-  g_simple_async_result_complete_in_idle (res);
-
-  g_object_unref (G_OBJECT (res));
+  g_object_unref (G_OBJECT (task));
 }
 
 static gpointer
@@ -1494,28 +1468,15 @@ _finish_async_request                   (GObject       *object,
                                          gpointer       source_tag,
                                          GError       **error)
 {
-  gpointer retval = NULL;
-
   g_return_val_if_fail (G_IS_OBJECT (object), NULL);
-  g_return_val_if_fail (G_IS_ASYNC_RESULT (res), NULL);
+  g_return_val_if_fail (G_IS_TASK (res), FALSE);
 
   /* Check for errors */
-  if (!_check_async_errors_on_finish (object, res, source_tag, error))
-    {
-      GSimpleAsyncResult *simple = NULL;
-      gpointer result = NULL;
+  if (_check_async_errors_on_finish (object, res, source_tag, error))
+    return NULL;
 
-      /* Get result */
-      simple = G_SIMPLE_ASYNC_RESULT (res);
-      result = g_simple_async_result_get_op_res_gpointer (simple);
-      if (result != NULL)
-        retval = result;
-      else
-        g_set_error_literal (error, FSP_ERROR, FSP_ERROR_OTHER,
-                             "Internal error");
-    }
-
-  return retval;
+  /* Get result or propagate error */
+  return g_task_propagate_pointer (G_TASK (res), error);
 }
 
 static void
@@ -1715,17 +1676,17 @@ fsp_session_set_default_proxy           (FspSession *self,
   g_return_if_fail (FSP_IS_SESSION (self));
 
   /* Ensure we clean the URI of a custom proxy, if present */
-  if (self->priv->proxy_uri)
-    soup_uri_free (self->priv->proxy_uri);
-  self->priv->proxy_uri = NULL;
+  if (self->proxy_uri)
+    soup_uri_free (self->proxy_uri);
+  self->proxy_uri = NULL;
 
   /* Explicitly enable or disable the feature in the session */
   if (enabled)
-    soup_session_add_feature_by_type (self->priv->soup_session, SOUP_TYPE_PROXY_RESOLVER_DEFAULT);
+    soup_session_add_feature_by_type (self->soup_session, SOUP_TYPE_PROXY_RESOLVER_DEFAULT);
   else
-    soup_session_remove_feature_by_type (self->priv->soup_session, SOUP_TYPE_PROXY_RESOLVER_DEFAULT);
+    soup_session_remove_feature_by_type (self->soup_session, SOUP_TYPE_PROXY_RESOLVER_DEFAULT);
 
-  self->priv->using_default_proxy = enabled;
+  self->using_default_proxy = enabled;
 }
 
 gboolean
@@ -1770,25 +1731,25 @@ fsp_session_set_custom_proxy            (FspSession *self,
     }
 
   /* Set the custom proxy (even if no valid data was provided) */
-  g_object_set (G_OBJECT (self->priv->soup_session),
+  g_object_set (G_OBJECT (self->soup_session),
                 SOUP_SESSION_PROXY_URI,
                 proxy_uri,
                 NULL);
 
-  was_using_default_proxy = self->priv->using_default_proxy;
-  self->priv->using_default_proxy = FALSE;
+  was_using_default_proxy = self->using_default_proxy;
+  self->using_default_proxy = FALSE;
 
   /* Update internal values if needed */
   if (was_using_default_proxy
-      || (!self->priv->proxy_uri && proxy_uri)
-      || (self->priv->proxy_uri && !proxy_uri)
-      || (self->priv->proxy_uri && proxy_uri && !soup_uri_equal (self->priv->proxy_uri, proxy_uri)))
+      || (!self->proxy_uri && proxy_uri)
+      || (self->proxy_uri && !proxy_uri)
+      || (self->proxy_uri && proxy_uri && !soup_uri_equal (self->proxy_uri, proxy_uri)))
     {
       /* Save internal reference to the proxy */
-      if (self->priv->proxy_uri)
-        soup_uri_free (self->priv->proxy_uri);
+      if (self->proxy_uri)
+        soup_uri_free (self->proxy_uri);
 
-      self->priv->proxy_uri = proxy_uri;
+      self->proxy_uri = proxy_uri;
 
       /* Proxy configuration actually changed */
       return TRUE;
@@ -1802,7 +1763,7 @@ fsp_session_get_api_key                 (FspSession *self)
 {
   g_return_val_if_fail (FSP_IS_SESSION (self), NULL);
 
-  return self->priv->api_key;
+  return self->api_key;
 }
 
 const gchar *
@@ -1810,7 +1771,7 @@ fsp_session_get_secret                  (FspSession *self)
 {
   g_return_val_if_fail (FSP_IS_SESSION (self), NULL);
 
-  return self->priv->secret;
+  return self->secret;
 }
 
 const gchar *
@@ -1818,7 +1779,7 @@ fsp_session_get_token                   (FspSession *self)
 {
   g_return_val_if_fail (FSP_IS_SESSION (self), NULL);
 
-  return self->priv->token;
+  return self->token;
 }
 
 void
@@ -1827,8 +1788,8 @@ fsp_session_set_token                   (FspSession  *self,
 {
   g_return_if_fail (FSP_IS_SESSION (self));
 
-  g_free (self->priv->token);
-  self->priv->token = g_strdup (token);
+  g_free (self->token);
+  self->token = g_strdup (token);
 }
 
 const gchar *
@@ -1836,7 +1797,7 @@ fsp_session_get_token_secret            (FspSession *self)
 {
   g_return_val_if_fail (FSP_IS_SESSION (self), NULL);
 
-  return self->priv->token_secret;
+  return self->token_secret;
 }
 
 void
@@ -1845,8 +1806,8 @@ fsp_session_set_token_secret            (FspSession  *self,
 {
   g_return_if_fail (FSP_IS_SESSION (self));
 
-  g_free (self->priv->token_secret);
-  self->priv->token_secret = g_strdup (token_secret);
+  g_free (self->token_secret);
+  self->token_secret = g_strdup (token_secret);
 }
 
 /* Get authorization URL */
@@ -1873,7 +1834,7 @@ fsp_session_get_auth_url                (FspSession          *self,
                          NULL);
 
   /* Perform the async request */
-  _perform_async_request (self->priv->soup_session, url,
+  _perform_async_request (self->soup_session, url,
                           _get_request_token_session_cb, G_OBJECT (self),
                           c, cb, fsp_session_get_auth_url, data);
 
@@ -1899,8 +1860,8 @@ fsp_session_get_auth_url_finish         (FspSession    *self,
   if (auth_token != NULL)
     {
       /* Save the temporaty data */
-      self->priv->tmp_token = g_strdup (auth_token->token);
-      self->priv->tmp_token_secret = g_strdup (auth_token->token_secret);
+      self->tmp_token = g_strdup (auth_token->token);
+      self->tmp_token_secret = g_strdup (auth_token->token_secret);
 
       /* Build the authorization url */
       auth_url = g_strdup_printf ("%s?oauth_token=%s",
@@ -1922,13 +1883,10 @@ fsp_session_complete_auth               (FspSession          *self,
                                          GAsyncReadyCallback  cb,
                                          gpointer             data)
 {
-  FspSessionPrivate *priv = NULL;
-
   g_return_if_fail (FSP_IS_SESSION (self));
   g_return_if_fail (cb != NULL);
 
-  priv = self->priv;
-  if (priv->tmp_token != NULL && priv->tmp_token_secret != NULL)
+  if (self->tmp_token != NULL && self->tmp_token_secret != NULL)
     {
       gchar *url = NULL;
 
@@ -1941,7 +1899,7 @@ fsp_session_complete_auth               (FspSession          *self,
                              NULL);
 
       /* Perform the async request */
-      _perform_async_request (priv->soup_session, url,
+      _perform_async_request (self->soup_session, url,
                               _get_access_token_soup_session_cb, G_OBJECT (self),
                               c, cb, fsp_session_complete_auth, data);
 
@@ -1953,8 +1911,7 @@ fsp_session_complete_auth               (FspSession          *self,
 
       /* Build and report error */
       err = g_error_new (FSP_ERROR, FSP_ERROR_OAUTH_NOT_AUTHORIZED_YET, "Not authorized yet");
-      g_simple_async_report_gerror_in_idle (G_OBJECT (self),
-                                            cb, data, err);
+      g_task_report_error (G_OBJECT (self), cb, data, fsp_session_complete_auth, err);
     }
 }
 
@@ -1992,13 +1949,10 @@ fsp_session_exchange_token              (FspSession          *self,
                                          GAsyncReadyCallback cb,
                                          gpointer             data)
 {
-  FspSessionPrivate *priv = NULL;
-
   g_return_if_fail (FSP_IS_SESSION (self));
   g_return_if_fail (cb != NULL);
 
-  priv = self->priv;
-  if (priv->token != NULL)
+  if (self->token != NULL)
     {
       gchar *url = NULL;
 
@@ -2011,7 +1965,7 @@ fsp_session_exchange_token              (FspSession          *self,
                              NULL);
 
       /* Perform the async request */
-      _perform_async_request (priv->soup_session, url,
+      _perform_async_request (self->soup_session, url,
                               _exchange_token_soup_session_cb, G_OBJECT (self),
                               c, cb, fsp_session_exchange_token, data);
 
@@ -2023,8 +1977,7 @@ fsp_session_exchange_token              (FspSession          *self,
 
       /* Build and report error */
       err = g_error_new (FSP_ERROR, FSP_ERROR_OAUTH_NOT_AUTHORIZED_YET, "Not authorized yet");
-      g_simple_async_report_gerror_in_idle (G_OBJECT (self),
-                                            cb, data, err);
+      g_task_report_error (G_OBJECT (self), cb, data, fsp_session_exchange_token, err);
     }
 }
 
@@ -2056,13 +2009,10 @@ fsp_session_check_auth_info             (FspSession          *self,
                                          GAsyncReadyCallback  cb,
                                          gpointer             data)
 {
-  FspSessionPrivate *priv = NULL;
-
   g_return_if_fail (FSP_IS_SESSION (self));
   g_return_if_fail (cb != NULL);
 
-  priv = self->priv;
-  if (priv->token != NULL)
+  if (self->token != NULL)
     {
       gchar *url = NULL;
 
@@ -2075,7 +2025,7 @@ fsp_session_check_auth_info             (FspSession          *self,
                              NULL);
 
       /* Perform the async request */
-      _perform_async_request (priv->soup_session, url,
+      _perform_async_request (self->soup_session, url,
                               _check_token_soup_session_cb, G_OBJECT (self),
                               c, cb, fsp_session_check_auth_info, data);
 
@@ -2087,8 +2037,7 @@ fsp_session_check_auth_info             (FspSession          *self,
 
       /* Build and report error */
       err = g_error_new (FSP_ERROR, FSP_ERROR_NOT_AUTHENTICATED, "No authenticated");
-      g_simple_async_report_gerror_in_idle (G_OBJECT (self),
-                                            cb, data, err);
+      g_task_report_error (G_OBJECT (self), cb, data, fsp_session_check_auth_info, err);
     }
 }
 
@@ -2115,13 +2064,10 @@ fsp_session_get_upload_status           (FspSession          *self,
                                          GAsyncReadyCallback cb,
                                          gpointer             data)
 {
-  FspSessionPrivate *priv = NULL;
-
   g_return_if_fail (FSP_IS_SESSION (self));
   g_return_if_fail (cb != NULL);
 
-  priv = self->priv;
-  if (priv->token != NULL)
+  if (self->token != NULL)
     {
       gchar *url = NULL;
 
@@ -2134,7 +2080,7 @@ fsp_session_get_upload_status           (FspSession          *self,
                              NULL);
 
       /* Perform the async request */
-      _perform_async_request (priv->soup_session, url,
+      _perform_async_request (self->soup_session, url,
                               _get_upload_status_soup_session_cb, G_OBJECT (self),
                               c, cb, fsp_session_get_upload_status, data);
 
@@ -2146,8 +2092,7 @@ fsp_session_get_upload_status           (FspSession          *self,
 
       /* Build and report error */
       err = g_error_new (FSP_ERROR, FSP_ERROR_NOT_AUTHENTICATED, "No authenticated");
-      g_simple_async_report_gerror_in_idle (G_OBJECT (self),
-                                            cb, data, err);
+      g_task_report_error (G_OBJECT (self), cb, data, fsp_session_get_upload_status, err);
     }
 }
 
@@ -2184,7 +2129,6 @@ fsp_session_upload                      (FspSession          *self,
                                          GAsyncReadyCallback  callback,
                                          gpointer             data)
 {
-  FspSessionPrivate *priv = NULL;
   SoupSession *soup_session = NULL;
   GHashTable *extra_params = NULL;
   AsyncRequestData *ard_clos = NULL;
@@ -2197,7 +2141,6 @@ fsp_session_upload                      (FspSession          *self,
   g_return_if_fail (fileuri != NULL);
 
   /* Get flickr proxy */
-  priv = self->priv;
   soup_session = _get_soup_session (self);
 
   /* Get extra params (those actually used for the picture) */
@@ -2206,7 +2149,7 @@ fsp_session_upload                      (FspSession          *self,
                                            safety_level, content_type, hidden);
 
   /* Add mandatory parameters according to OAuth specification */
-  _fill_hash_table_with_oauth_params (extra_params, priv->api_key, priv->token);
+  _fill_hash_table_with_oauth_params (extra_params, self->api_key, self->token);
 
   /* OAuth requires to encode some fields just to calculate the
      signature, so do some extra encoding now and undo it later */
@@ -2215,7 +2158,7 @@ fsp_session_upload                      (FspSession          *self,
   _encode_param_from_table_for_signature (extra_params, "tags");
 
   /* Build the api signature and add it to the hash table */
-  signing_key = g_strdup_printf ("%s&%s", priv->secret, priv->token_secret);
+  signing_key = g_strdup_printf ("%s&%s", self->secret, self->token_secret);
   api_sig = _get_api_signature_from_hash_table (FLICKR_API_UPLOAD_URL, extra_params, signing_key,
                                                 "POST", AUTHORIZATION_METHOD_OAUTH_1);
 
