@@ -33,33 +33,13 @@
 
 G_BEGIN_DECLS
 
-#define FROGR_TYPE_CONFIG            (frogr_config_get_type())
-#define FROGR_IS_CONFIG(obj)         (G_TYPE_CHECK_INSTANCE_TYPE(obj, FROGR_TYPE_CONFIG))
-#define FROGR_IS_CONFIG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE(klass,  FROGR_TYPE_CONFIG))
-#define FROGR_CONFIG(obj)            (G_TYPE_CHECK_INSTANCE_CAST(obj, FROGR_TYPE_CONFIG, FrogrConfig))
-#define FROGR_CONFIG_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST(klass,  FROGR_TYPE_CONFIG, FrogrConfigClass))
-#define FROGR_CONFIG_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS(obj,  FROGR_TYPE_CONFIG, FrogrConfigClass))
+#define FROGR_TYPE_CONFIG (frogr_config_get_type())
+
+G_DECLARE_FINAL_TYPE (FrogrConfig, frogr_config, FROGR, CONFIG, GObject)
 
 /* Increase this when changing the xml schema for storing settings */
 #define SETTINGS_CURRENT_VERSION "2"
 
-typedef struct _FrogrConfig        FrogrConfig;
-typedef struct _FrogrConfigClass   FrogrConfigClass;
-
-struct _FrogrConfig
-{
-  GObject parent_instance;
-};
-
-
-struct _FrogrConfigClass
-{
-  GObjectClass parent_class;
-};
-
-
-GType frogr_config_get_type (void) G_GNUC_CONST;
-
 typedef enum {
   SORT_AS_LOADED,
   SORT_BY_TITLE,
